#!/usr/bin/perl -w

# Averist example script
# Copyright (C) 2000 Henrik Edlund <henrik@edlund.org>
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA.



use strict;
use Averist;

use vars qw($Product_Name $Product_Version);
$Product_Name = 'Averist example script';
$Product_Version = '0.1.2';



my %query;
my $username;
my $session;

# I'll just borrow the CGI query parser from Averist for this example.

%query = Averist::_parse_cgi_query();

# If this would have been a frame-based application, then we would use
# Averist::login(1) for the first loading (creating HTML code for the frame
# set), and then when called again (creating the actual frames) we would use
# Averist::login(0) so that we don't destroy session data when loading each
# frame. But as this is not a frame-based application we simply set the
# session data each time (by using 1).

# As Averist will normally parse the CGI query and make it unavailable to the
# calling script, you can choose to parse it yourself and pass a reference to
# it to Averist instead. Then you would do Averist::login(1, \%query) where
# %query is the parsed query structure.

($username, $session) = Averist::login(1, \%query);

# If we clicked the Logout button we logout (really!)

if (defined($query{'logout'})) {
    Averist::logout();
}

# Print the page header

print "Content-type: text/html\n\n";
print "<html>\n";
print "<head><title>$Product_Name $Product_Version</title></head>\n";
print "<body>\n";
print "<h1>$Product_Name $Product_Version</h1>\n";

# Check if we have a successful (re-)authentication or if we logged out

if (defined($query{'logout'})) {
    print "<p>You are now logged out!</p>\n";
    print "<form method=\"post\">\n";
    print "Username: <input type=\"text\" name=\"username\"><br />\n";
    print "Password: <input type=\"password\" name=\"password\"><br />\n";
    print "<input type=\"submit\" value=\"Login\">\n";
    print "</form>\n";
}
elsif (defined($session)) {
    print "<p>You have (re-)authenticated as ";
    print "<strong>$username</strong>.</p>\n";
    print "<form method=\"post\">\n";
    if ($Averist::Config{'events'}{'reauthentication'}{'remote'} eq 'cgi') {
	print "<input type=\"hidden\" name=\"username\" ";
	print "value=\"$username\">\n";
	print "<input type=\"hidden\" name=\"session\" ";
	print "value=\"$session\">\n";
    }
    print "<input type=\"submit\" value=\"Reload\"> ";
    print "<input type=\"submit\" name=\"logout\" value=\"Logout\">\n";
    print "</form>\n";
}
else {
    if (defined($username)) {
	print "<p>Reauthentication needed or bad password specified.</p>\n";
    }
    else {
	print "<p>Authentication needed or bad username specified.</p>\n";
	$username = '';
    }
    print "<form method=\"post\">\n";
    print "Username: <input type=\"text\" name=\"username\" ";
    print "value=\"$username\"><br />\n";
    print "Password: <input type=\"password\" name=\"password\"><br />\n";
    print "<input type=\"submit\" value=\"Login\">\n";
    print "</form>\n";
}

# Print the page footer

print "</body>\n";
print "</html>\n";
